Index: wp-admin/includes/deprecated.php
===================================================================
--- wp-admin/includes/deprecated.php	(revision 17501)
+++ wp-admin/includes/deprecated.php	(working copy)
@@ -502,7 +502,7 @@
 			$this->query_where .= " AND $wpdb->users.ID = $wpdb->usermeta.user_id AND meta_key = '{$level_key}'";
 		}
 
-		do_action_ref_array( 'pre_user_search', array( &$this ) );
+		do_action( 'pre_user_search', $this );
 	}
 
 	/**
Index: wp-admin/includes/user.php
===================================================================
--- wp-admin/includes/user.php	(revision 17501)
+++ wp-admin/includes/user.php	(working copy)
@@ -176,7 +176,7 @@
 	}
 
 	// Allow plugins to return their own errors.
-	do_action_ref_array('user_profile_update_errors', array ( &$errors, $update, &$user ) );
+	do_action('user_profile_update_errors', $errors, $update, $user );
 
 	if ( $errors->get_error_codes() )
 		return $errors;
Index: wp-includes/admin-bar.php
===================================================================
--- wp-includes/admin-bar.php	(revision 17501)
+++ wp-includes/admin-bar.php	(working copy)
@@ -57,7 +57,7 @@
 
 	$wp_admin_bar->load_user_locale_translations();
 
-	do_action_ref_array( 'admin_bar_menu', array( &$wp_admin_bar ) );
+	do_action( 'admin_bar_menu', $wp_admin_bar );
 
 	do_action( 'wp_before_admin_bar_render' );
 
Index: wp-includes/class-wp.php
===================================================================
--- wp-includes/class-wp.php	(revision 17501)
+++ wp-includes/class-wp.php	(working copy)
@@ -298,7 +298,7 @@
 
 		$this->query_vars = apply_filters('request', $this->query_vars);
 
-		do_action_ref_array('parse_request', array(&$this));
+		do_action( 'parse_request', $this );
 	}
 
 	/**
@@ -373,7 +373,7 @@
 		if ( $exit_required )
 			exit();
 
-		do_action_ref_array('send_headers', array(&$this));
+		do_action( 'send_headers', $this );
 	}
 
 	/**
@@ -501,7 +501,7 @@
 		$this->query_posts();
 		$this->handle_404();
 		$this->register_globals();
-		do_action_ref_array('wp', array(&$this));
+		do_action( 'wp', $this );
 	}
 
 	/**
Index: wp-includes/class.wp-scripts.php
===================================================================
--- wp-includes/class.wp-scripts.php	(revision 17501)
+++ wp-includes/class.wp-scripts.php	(working copy)
@@ -31,7 +31,7 @@
 	var $default_dirs;
 
 	function __construct() {
-		do_action_ref_array( 'wp_default_scripts', array(&$this) );
+		do_action( 'wp_default_scripts', $this );
 	}
 
 	/**
Index: wp-includes/class.wp-styles.php
===================================================================
--- wp-includes/class.wp-styles.php	(revision 17501)
+++ wp-includes/class.wp-styles.php	(working copy)
@@ -28,7 +28,7 @@
 	var $default_dirs;
 
 	function __construct() {
-		do_action_ref_array( 'wp_default_styles', array(&$this) );
+		do_action( 'wp_default_styles', $this );
 	}
 
 	function do_item( $handle ) {
Index: wp-includes/comment.php
===================================================================
--- wp-includes/comment.php	(revision 17501)
+++ wp-includes/comment.php	(working copy)
@@ -221,7 +221,7 @@
 		);
 
 		$this->query_vars = wp_parse_args( $query_vars, $defaults );
-		do_action_ref_array( 'pre_get_comments', array( &$this ) );
+		do_action( 'pre_get_comments', $this );
 		extract( $this->query_vars, EXTR_SKIP );
 
 		// $args can be whatever, only use the args defined in defaults to compute the key
Index: wp-includes/feed.php
===================================================================
--- wp-includes/feed.php	(revision 17501)
+++ wp-includes/feed.php	(working copy)
@@ -535,7 +535,7 @@
 	$feed->set_cache_class('WP_Feed_Cache');
 	$feed->set_file_class('WP_SimplePie_File');
 	$feed->set_cache_duration(apply_filters('wp_feed_cache_transient_lifetime', 43200, $url));
-	do_action_ref_array( 'wp_feed_options', array( &$feed, $url ) );
+	do_action( 'wp_feed_options', $feed, $url );
 	$feed->init();
 	$feed->handle_content_type();
 
Index: wp-includes/rewrite.php
===================================================================
--- wp-includes/rewrite.php	(revision 17501)
+++ wp-includes/rewrite.php	(working copy)
@@ -1562,7 +1562,7 @@
 		else
 			$this->rules = array_merge($this->extra_rules_top, $robots_rewrite, $default_feeds, $registration_pages, $root_rewrite, $comments_rewrite, $search_rewrite,  $author_rewrite, $date_rewrite, $post_rewrite, $page_rewrite, $this->extra_rules);
 
-		do_action_ref_array('generate_rewrite_rules', array(&$this));
+		do_action( 'generate_rewrite_rules', $this );
 		$this->rules = apply_filters('rewrite_rules_array', $this->rules);
 
 		return $this->rules;
Index: wp-includes/user.php
===================================================================
--- wp-includes/user.php	(revision 17501)
+++ wp-includes/user.php	(working copy)
@@ -531,7 +531,7 @@
 			$this->query_where .= " AND $wpdb->users.ID NOT IN ($ids)";
 		}
 
-		do_action_ref_array( 'pre_user_query', array( &$this ) );
+		do_action( 'pre_user_query', $this );
 	}
 
 	/**
Index: wp-includes/widgets.php
===================================================================
--- wp-includes/widgets.php	(revision 17501)
+++ wp-includes/widgets.php	(working copy)
@@ -270,7 +270,7 @@
 			$return = $this->form($instance);
 			// add extra fields in the widget form - be sure to set $return to null if you add any
 			// if the widget has no form the text echoed from the default form method can be hidden using css
-			do_action_ref_array( 'in_widget_form', array(&$this, &$return, $instance) );
+			do_action_ref_array( 'in_widget_form', array($this, &$return, $instance) );
 		}
 		return $return;
 	}

Index: wp-includes/pluggable.php
===================================================================
--- wp-includes/pluggable.php	(revision 17501)
+++ wp-includes/pluggable.php	(working copy)
@@ -256,7 +256,7 @@
  * @uses apply_filters() Calls 'wp_mail_from_name' hook to get the from address name.
  * @uses apply_filters() Calls 'wp_mail_content_type' hook to get the email content type.
  * @uses apply_filters() Calls 'wp_mail_charset' hook to get the email charset
  * @uses do_action_ref_array() Calls 'phpmailer_init' hook on the reference to
  *		phpmailer object.
  * @uses PHPMailer
  * @
@@ -459,7 +459,7 @@
 		}
 	}
 
-	do_action_ref_array( 'phpmailer_init', array( &$phpmailer ) );
+	do_action( 'phpmailer_init', $phpmailer );
 
 	// Send!
 	$result = @$phpmailer->Send();
@@ -256,7 +256,7 @@
  * @uses apply_filters() Calls 'wp_mail_content_type' hook to get the email content type.
  * @uses apply_filters() Calls 'wp_mail_charset' hook to get the email charset
- * @uses do_action_ref_array() Calls 'phpmailer_init' hook on the reference to
+ * @uses do_action() Calls 'phpmailer_init' hook on the reference to
  *		phpmailer object.
  * @uses PHPMailer
Index: wp-includes/query.php
===================================================================
--- wp-includes/query.php	(revision 17501)
+++ wp-includes/query.php	(working copy)
@@ -1627,7 +1627,7 @@
 		if ( '404' == $qv['error'] )
 			$this->set_404();
 
-		do_action_ref_array('parse_query', array(&$this));
+		do_action( 'parse_query', $this );
 	}
 
 	/*
@@ -1868,7 +1868,7 @@
 	 *
 	 * @since 1.5.0
 	 * @access public
 	 * @uses do_action_ref_array() Calls 'pre_get_posts' hook before retrieving posts.
 	 *
 	 * @return array List of posts.
 	 */
@@ -1877,7 +1877,7 @@
 
 		$this->parse_query();
 
-		do_action_ref_array('pre_get_posts', array(&$this));
+		do_action( 'pre_get_posts', $this );
 
 		// Shorthand.
 		$q = &$this->query_vars;
@@ -2732,14 +2732,14 @@
 	 * @since 1.5.0
 	 * @access public
 	 * @uses $post
 	 * @uses do_action_ref_array() Calls 'loop_start' if loop has just started
 	 */
 	function the_post() {
 		global $post;
 		$this->in_the_loop = true;
 
 		if ( $this->current_post == -1 ) // loop has just started
-			do_action_ref_array('loop_start', array(&$this));
+			do_action( 'loop_start', $this );
 
 		$post = $this->next_post();
 		setup_postdata($post);
@@ -2752,7 +2752,7 @@
 	 *
 	 * @since 1.5.0
 	 * @access public
 	 * @uses do_action_ref_array() Calls 'loop_end' if loop is ended
 	 *
 	 * @return bool True if posts are available, false if end of loop.
 	 */
@@ -2760,7 +2760,7 @@
 		if ( $this->current_post + 1 < $this->post_count ) {
 			return true;
 		} elseif ( $this->current_post + 1 == $this->post_count && $this->post_count > 0 ) {
-			do_action_ref_array('loop_end', array(&$this));
+			do_action( 'loop_end', $this );
 			// Do some cleaning up after the loop
 			$this->rewind_posts();
 		}
@@ -3485,7 +3485,7 @@
  * @since 1.5.0
  *
  * @param object $post Post data.
- * @uses do_action_ref_array() Calls 'the_post'
+ * @uses do_action() Calls 'the_post'
  * @return bool True when finished.
  */
 function setup_postdata($post) {
@@ -3518,7 +3518,7 @@
 		$multipage = 0;
 	}
 
-	do_action_ref_array('the_post', array(&$post));
+	do_action( 'the_post', $post );
 
 	return true;
 }
@@ -1868,7 +1868,7 @@
 	 * @since 1.5.0
 	 * @access public
-	 * @uses do_action_ref_array() Calls 'pre_get_posts' hook before retrieving posts.
+	 * @uses do_action() Calls 'pre_get_posts' hook before retrieving posts.
 	 *
 	 * @return array List of posts.
@@ -2732,14 +2732,14 @@
 	 * @access public
 	 * @uses $post
-	 * @uses do_action_ref_array() Calls 'loop_start' if loop has just started
+	 * @uses do_action() Calls 'loop_start' if loop has just started
 	 */
 	function the_post() {
@@ -2752,7 +2752,7 @@
 	 * @since 1.5.0
 	 * @access public
-	 * @uses do_action_ref_array() Calls 'loop_end' if loop is ended
+	 * @uses do_action() Calls 'loop_end' if loop is ended
 	 *
 	 * @return bool True if posts are available, false if end of loop.